diff --git a/controllers/plugin_dbui.py b/controllers/plugin_dbui.py
index eac17387696b521071f0f35953c099efa3e3bfd0..b32852a54439db9081e102520814e489b053862b 100644
--- a/controllers/plugin_dbui.py
+++ b/controllers/plugin_dbui.py
@@ -32,8 +32,8 @@ def index():
 
     DESCRIPTION
         Main controller to launch the plugin.
         Load the extjs librairy and the associated css files.
         Load the javascript librairy for the plugin.
         Define view.
 
     PUBLIC PARAMETERS WHICH CAN BE SET VIA THE PLUGINMANAGER
@@ -70,11 +70,11 @@ def index():
         http://localhost:8000/application/plugin_dbui?script=foo&debug
 
     """
     # check the presence of the extjs plugin
     server_path = os.path.join('applications', request.application)
     path = os.path.join(server_path, 'static', 'plugin_extjs')
     if not os.path.exists(path):
-        raise HTTP(500, 'The plugin extjs is not install !')
+        raise HTTP(500, 'The plugin ExtJS is not install !')
 
     # is the plugin MatJax ?
     path = os.path.join(server_path, 'static', 'plugin_mathjax')
@@ -93,7 +93,7 @@ def index():
     if script not in os.listdir(script_path):
         return 'Request script "%s" does not exist !!!' % script
 
-    # css files
+    # CSS files
     base = os.path.join(os.path.sep, request.application)
     extjs = os.path.join(base, 'static', 'plugin_extjs')
     response.files.append(os.path.join(extjs, 'resources', 'css', 'ext-all.css')) 
@@ -187,7 +187,7 @@ def configuration():
     Relies on Ext.Direct see specification:
     http://www.extjs.com/products/extjs/direct.php
 
-    Act as a router for the cfgSvc service (see Ext.Direct Extjs 3.1.1)
+    Act as a router for the cfgSvc service (see Ext.Direct ExtJS 3.1.1)
     Decode the raw HTTP post request:
     {action: "cfgSvc", method: x, data: y, tip: i, type: "rpc"}
@@ -32,8 +32,8 @@ def index():
     DESCRIPTION
         Main controller to launch the plugin.
-        Load the extjs librairy and the associated css files.
-        Load the javascript librairy for the plugin.
+        Load the ExtJS library and the associated CSS files.
+        Load the javascript library for the plugin.
         Define view.
 
@@ -70,11 +70,11 @@ def index():
 
     """
-    # check the presence of the extjs plugin
+    # check the presence of the ExtJS plugin
     server_path = os.path.join('applications', request.application)
     path = os.path.join(server_path, 'static', 'plugin_extjs')